<?php

namespace Drupal\highlightjs_input_filter\Plugin\Filter;

use Drupal\filter\FilterProcessResult;
use Drupal\filter\Plugin\FilterBase;

/**
 * Provides a filter to attach assets for <code> tags.
 *
 * @Filter(
 *   id = "filter_highlightjs",
 *   title = @Translation("Highlight code using highlight.js"),
 *   description = @Translation("Highlights code inside <code>&lt;pre&gt;&lt;code class='language-*'&gt;</code> tags."),
 *   type = Drupal\filter\Plugin\FilterInterface::TYPE_TRANSFORM_REVERSIBLE
 * )
 */
class HighlightJs extends FilterBase {

  /**
   * {@inheritdoc}
   */
  public function process($text, $langcode) {
    $result = new FilterProcessResult($text);
    if (stristr($text, '<code') === FALSE || stristr($text, 'language-') === FALSE) {
      return $result;
    }

    // Add needed JS.
    $result->addAttachments([
      'library' => [
        'highlight/highlightjs',
      ],
    ]);

    return $result;
  }

  /**
   * {@inheritdoc}
   */
  public function tips($long = FALSE) {
    return $this->t('Add assets for code tags');
  }

}
